@@ -19,7 +19,7 @@ class RangeName:
     """Generates a range name for updating a worksheet in Google Sheets or
     Excel, e.g. 'A1:B5'.
 
-    Attributes
+    Parameters
     ----------
     rows : int
         The number of total rows that should be updated in the worksheet.
@@ -53,8 +53,8 @@ class RangeName:
         Set to True if you would like to override the predetermined column
         limit. Default is False.
 
-    Other Attributes
-    ----------------
+    Attributes
+    ----------
     range_name:
         Only accessible after the RangeName object is initialized. Generates
         the range name, e.g. 'A2:EE1000' per the provided arguments.
@@ -126,16 +126,17 @@ class RangeName:
     override_col_limit: bool = field(
         default=False, validator=instance_of(bool)
     )
+    range_name: str = field(init=False)
 
-    def __post_init_attrs__(self):
+    def __attrs_post_init__(self):
         self.buffer = (
             self.buffer.upper()
             if isinstance(self.buffer, str)
             else self.buffer
         )
+        self.range_name = self._range_name()
 
-    @property
-    def range_name(self) -> str:
+    def _range_name(self) -> str:
         # creating prefix
         match (buffer_is_str := isinstance(self.buffer, str)):
             case True:
